@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import re
 from subprocess import run
 
@@ -8,13 +10,13 @@ import contourpy
 
 
 # From PEP440 appendix.
-def version_is_canonical(version):
+def version_is_canonical(version: str) -> bool:
     return re.match(
         r"^([1-9][0-9]*!)?(0|[1-9][0-9]*)(\.(0|[1-9][0-9]*))*((a|b|rc)(0|[1-9][0-9]*))?"
         r"(\.post(0|[1-9][0-9]*))?(\.dev(0|[1-9][0-9]*))?$", version) is not None
 
 
-def test_cppcheck():
+def test_cppcheck() -> None:
     # Skip test if cppcheck is not installed.
     cmd = ["cppcheck", "--version"]
     try:
@@ -22,7 +24,7 @@ def test_cppcheck():
     except FileNotFoundError:
         pytest.skip()
 
-    cpp_version = Version(proc.stdout.decode('utf-8').strip().split()[-1])
+    cpp_version = Version(proc.stdout.decode("utf-8").strip().split()[-1])
 
     # Note excluding mpl2005 code.
     cmd = [
@@ -36,27 +38,20 @@ def test_cppcheck():
     assert proc.returncode == 0, f"cppcheck issues:\n{proc.stderr.decode('utf-8')}"
 
 
-def test_flake8():
-    cmd = ["flake8"]
+def test_mypy() -> None:
+    # Skip test if mypy is not installed.
+    cmd = ["mypy", "--version"]
     try:
         proc = run(cmd, capture_output=True)
     except FileNotFoundError:
         pytest.skip()
 
-    assert proc.returncode == 0, f"Flake8 issues:\n{proc.stdout.decode('utf-8')}"
+    cmd = ["mypy"]
+    proc = run(cmd, capture_output=True)
+    assert proc.returncode == 0, print(f"mypy issues:\n{proc.stdout.decode('utf-8')}")
 
 
-def test_isort():
-    cmd = ["isort", ".", "--diff", "--check-only"]
-    try:
-        proc = run(cmd, capture_output=True)
-    except FileNotFoundError:
-        pytest.skip()
-
-    assert proc.returncode == 0, f"isort issues:\n{proc.stderr.decode('utf-8')}"
-
-
-def test_version():
+def test_version() -> None:
     version_python = contourpy.__version__
     assert version_is_canonical(version_python)
     version_cxx = contourpy._contourpy.__version__
